from wagtail.core.blocks import (
    StructBlock,
    StreamBlock,
    TextBlock,
)
from wagtail.documents.blocks import DocumentChooserBlock


class DocumentActionItemBlock(StructBlock):
    label = TextBlock(required=True)
    document = DocumentChooserBlock(required=True)

    class Meta:
        icon = "fa-file"
        template = "wagtailgridder/blocks/document_action_item.html"
        help_text = "Select a document and label for the button."


class URLActionItemBlock(StructBlock):
    label = TextBlock(required=True)
    url = TextBlock(required=True)

    class Meta:
        icon = "fa-link"
        template = "wagtailgridder/blocks/url_action_item.html"
        help_text = "Select a URL and label for the button."


class PlaceholderBlock(StructBlock):
    pass

    class Meta:
        icon = "fa-square-o"
        template = "wagtailgridder/blocks/placeholder_action_item.html"
        help_text = "Empty placeholder to align buttons in rows."


class ActionItemStreamBlock(StreamBlock):
    document_button = DocumentActionItemBlock(icon="fa-file")
    url_button = URLActionItemBlock(icon="fa-link")
    placeholder = PlaceholderBlock(icon="fa-square-o")


class ButtonSectionBlock(StructBlock):
    action_items = ActionItemStreamBlock(
        help_text="A button or URL within a button section."
    )

    class Meta:
        icon = "fa-list"
        template = "wagtailgridder/blocks/button_section.html"
        help_text = "Sections divide the action item area into rows."


class ButtonBlock(StreamBlock):
    button_section = ButtonSectionBlock()

    class Meta:
        help_text = "A row of buttons in the expanded grid item area."



from django.conf import settings


def get_clear_cache():
    """
    Default to clearing the cache after each page edit.
    """

    return getattr(settings, "WAGTAILGRIDDER_CLEAR_CACHE", False)


def get_grid_item_parent_page_types():
    """
    Default parent page types for grid items.
    """

    return getattr(
        settings,
        "WAGTAILGRIDDER_GRID_ITEM_PARENT_PAGE_TYPES",
        ["GridIndexPage"]
    )

def get_grid_index_page_subpage_types():
    """
    Default subpage types for grid index pages.
    """

    return getattr(
        settings,
        "WAGTAILGRIDDER_GRID_INDEX_PAGE_SUBPAGE_TYPES",
        ["GridItem"]
    )



from django.db import models
from django.forms import CheckboxSelectMultiple
from django.utils import timezone

from wagtail.core.fields import StreamField, RichTextField
from wagtail.core.models import Page, Orderable
from wagtail.admin.edit_handlers import (
    FieldPanel,
    StreamFieldPanel,
    PageChooserPanel,
    InlinePanel,
    MultiFieldPanel,
)
from wagtail.images.edit_handlers import ImageChooserPanel
from wagtail.search import index

from modelcluster.fields import ParentalKey, ParentalManyToManyField
from modelcluster.tags import ClusterTaggableManager
from taggit.models import TaggedItemBase

from .blocks import ButtonBlock
from .settings import get_grid_item_parent_page_types, get_grid_index_page_subpage_types


class GridItemTag(TaggedItemBase):
    """
    Object to hold existing tags for Grid Items.
    """

    content_object = ParentalKey(
        "GridItem", related_name="tagged_items", on_delete=models.CASCADE,
    )


class GridCategory(models.Model):
    """
    Categories which a grid item can belong to. A grid item can belong to many
    categories. Categories can be selected from the top of the grid index page.
    """

    name = models.CharField(max_length=255)

    def __str__(self):
        return self.name

    class Meta:
        verbose_name_plural = "grid categories"


class GridItem(Page):
    """
    The fields needed to properly display a grid item.
    The template will omit any fields not included automagically.
    """

    parent_page_types = get_grid_item_parent_page_types()

    class Meta:
        verbose_name = "Grid Item"

    summary_image = models.ForeignKey(
        "wagtailimages.Image",
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name="+",
    )
    summary_text = RichTextField(
        "Summary",
        default="",
        help_text='The summary will appear in the item "card" view.',
    )
    description_image = models.ForeignKey(
        "wagtailimages.Image",
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name="+",
        help_text="This image will appear in the expanded area when populated.",
    )
    description_text = RichTextField(
        "Full Description",
        null=True,
        blank=True,
        help_text="This description will appear in the expanded area when populated.",
    )
    description_video = models.URLField(
        null=True,
        blank=True,
        help_text="This video will be embedded in the expanded area when populated.",
    )
    landing_page_text = RichTextField(
        "Landing Page Text",
        null=True,
        blank=True,
        help_text="This is the text which will appear on the grid item's landing page.",
    )
    buttons = StreamField(ButtonBlock(), null=True)
    tags = ClusterTaggableManager(through=GridItemTag, blank=True)
    categories = ParentalManyToManyField("GridCategory", blank=True)
    modified = models.DateTimeField("Page Modified", null=True)

    search_fields = Page.search_fields + [
        index.SearchField("summary_text"),
        index.SearchField("description_text"),
        index.SearchField("landing_page_text"),
    ]

    CARD_PANELS = [
        ImageChooserPanel("summary_image"),
        FieldPanel("summary_text"),
    ]

    DETAIL_PANELS = [
        ImageChooserPanel("description_image"),
        FieldPanel("description_text"),
        FieldPanel("description_video"),
        FieldPanel("landing_page_text"),
    ]

    META_PANELS = [
        FieldPanel("tags"),
        FieldPanel("categories", widget=CheckboxSelectMultiple),
    ]

    content_panels = Page.content_panels + [
        MultiFieldPanel(
            CARD_PANELS, heading="Card Information", classname="collapsible",
        ),
        MultiFieldPanel(
            DETAIL_PANELS,
            heading="Expanded Description & Page Information",
            classname="collapsible",
        ),
        StreamFieldPanel("buttons",),
        MultiFieldPanel(META_PANELS, heading="Metadata", classname="collapsible",),
    ]

    def save(self, *args, **kwargs):
        self.modified = timezone.now()
        super(GridItem, self).save(*args, **kwargs)


class GridIndexGridItemRelationship(Orderable, models.Model):
    """
    Allows the content creator to associate Grid Items on a
    Grid Index Page.
    """

    grid_relationship = ParentalKey(
        "GridIndexPage",
        related_name="grid_index_grid_item_relationship",
        on_delete=models.CASCADE,
    )
    grid_item = models.ForeignKey(
        "GridItem",
        related_name="+",
        help_text="Add a grid item to the page",
        verbose_name="Grid Items",
        on_delete=models.CASCADE,
    )
    panels = [PageChooserPanel("grid_item")]


class GridIndexPage(Page):
    """
    Index page for Grid Items.
    This links the grid items to the categories and provides a page to display them on.
    """
    subpage_types = get_grid_index_page_subpage_types()

    hero_background_image = models.ForeignKey(
        "wagtailimages.Image",
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name="+",
        help_text="The background image for the hero section. This triggers the "
        "section to be displayed if an image is selected.",
    )

    hero_logo_image = models.ForeignKey(
        "wagtailimages.Image",
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name="+",
        help_text="The logo image to be displayed over the background image.",
    )

    hero_description = RichTextField(
        null=True,
        blank=True,
        help_text="Text to be displayed beneath the logo over the background image.",
    )

    hero_button_text = models.CharField(
        null=True,
        blank=True,
        max_length=255,
        help_text="Text for the call-to-action button beneath the text and logo over "
        "the background image.",
    )

    hero_button_url = models.CharField(
        null=True,
        blank=True,
        max_length=255,
        help_text="URL for the call-to-action button beneath the text and logo over "
        "the background image.",
    )

    featured_description = RichTextField(
        null=True,
        blank=True,
        help_text="Text to be displayed below the hero image next to the featured "
        "items.",
    )

    featured_grid_item_1 = models.ForeignKey(
        "GridItem",
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name="+",
        help_text="First featured grid item underneath the hero image.",
        verbose_name="Featured Item One",
    )

    featured_grid_item_2 = models.ForeignKey(
        "GridItem",
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name="+",
        help_text="Second featured grid item underneath the hero image.",
        verbose_name="Featured Item Two,",
    )

    @property
    def grid_items(self):
        grid_items = [n.grid_item for n in self.grid_index_grid_item_relationship.all()]
        return grid_items

    @property
    def categories(self):
        grid_item_categories = (
            GridIndexGridItemRelationship.objects.values_list(
                "grid_item__categories__name"
            )
            .filter(grid_relationship__id=self.id,)
            .order_by("grid_item__categories__name",)
            .distinct()
        )

        categories = []

        for gic in grid_item_categories:
            if gic[0] is not None:
                categories.append(gic[0])

        return categories

    HERO_PANELS = [
        ImageChooserPanel("hero_background_image"),
        ImageChooserPanel("hero_logo_image"),
        FieldPanel("hero_description"),
        FieldPanel("hero_button_text"),
        FieldPanel("hero_button_url"),
        FieldPanel("featured_description"),
        PageChooserPanel("featured_grid_item_1"),
        PageChooserPanel("featured_grid_item_2"),
    ]

    content_panels = Page.content_panels + [
        MultiFieldPanel(
            HERO_PANELS,
            heading="Hero Section (Optional)",
            classname="collapsible collapsed",
        ),
        InlinePanel(
            "grid_index_grid_item_relationship",
            label="grid_items",
            panels=None,
            min_num=1,
        ),
    ]

    search_fields = Page.search_fields + [
        index.SearchField("hero_description"),
    ]

    class Meta:
        verbose_name = "Grid Index Page"

    def __str__(self):
        return "{0}".format(self.grid_items,)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.10 on 2018-02-06 15:09
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import modelcluster.contrib.taggit
import modelcluster.fields

try:
    from wagtail.core import blocks as core_blocks
    from wagtail.core import fields as core_fields
    from wagtail.documents import blocks as docs_blocks
except ImportError:
    from wagtail.wagtailcore import blocks as core_blocks
    from wagtail.wagtailcore import fields as core_fields
    from wagtail.wagtaildocs import blocks as docs_blocks


class Migration(migrations.Migration):

    replaces = [
        ("wagtailgridder", "0001_initial"),
        ("wagtailgridder", "0002_griditem_landing_page_text"),
        ("wagtailgridder", "0003_remove_griditem_target_url"),
        ("wagtailgridder", "0004_auto_20161103_1446"),
        ("wagtailgridder", "0005_auto_20161117_0715"),
        ("wagtailgridder", "0006_auto_20170217_1354"),
        ("wagtailgridder", "0007_auto_20170217_1404"),
        ("wagtailgridder", "0008_auto_20170320_1707"),
        ("wagtailgridder", "0009_gridindexpage_logo_image"),
        ("wagtailgridder", "0010_auto_20170403_1347"),
        ("wagtailgridder", "0011_auto_20170404_1454"),
        ("wagtailgridder", "0012_auto_20170607_1317"),
    ]

    initial = True

    dependencies = [
        ("wagtailimages", "0018_remove_rendition_filter"),
        ("taggit", "0002_auto_20150616_2121"),
        ("wagtailimages", "0013_make_rendition_upload_callable"),
        ("wagtailcore", "0029_unicode_slugfield_dj19"),
    ]

    operations = [
        migrations.CreateModel(
            name="GridCategory",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255)),
            ],
            options={"verbose_name_plural": "grid categories",},
        ),
        migrations.CreateModel(
            name="GridIndexGridItemRelationship",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "sort_order",
                    models.IntegerField(blank=True, editable=False, null=True),
                ),
            ],
            options={"ordering": ["sort_order"], "abstract": False,},
        ),
        migrations.CreateModel(
            name="GridIndexPage",
            fields=[
                (
                    "page_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="wagtailcore.Page",
                    ),
                ),
            ],
            options={"verbose_name": "Grid Index Page",},
            bases=("wagtailcore.page",),
        ),
        migrations.CreateModel(
            name="GridItem",
            fields=[
                (
                    "page_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="wagtailcore.Page",
                    ),
                ),
                (
                    "summary",
                    core_fields.RichTextField(
                        default="",
                        help_text='The summary will appear in the item "card" view.',
                        verbose_name="Summary",
                    ),
                ),
                (
                    "full_desc",
                    core_fields.RichTextField(
                        default="",
                        help_text="The description will appear when the grid item is clicked and expanded.",
                        verbose_name="Full Description",
                    ),
                ),
                (
                    "target_url",
                    models.URLField(
                        blank=True,
                        default="",
                        help_text="The URL for this grid item, if it is not a full Django App.",
                        verbose_name="URL",
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(null=True, verbose_name="Page Modified"),
                ),
                (
                    "buttons",
                    core_fields.StreamField(
                        (
                            (
                                "button_section",
                                core_blocks.StructBlock(
                                    (
                                        (
                                            "action_items",
                                            core_blocks.StreamBlock(
                                                (
                                                    (
                                                        "document_button",
                                                        core_blocks.StructBlock(
                                                            (
                                                                (
                                                                    "label",
                                                                    core_blocks.TextBlock(
                                                                        required=True
                                                                    ),
                                                                ),
                                                                (
                                                                    "document",
                                                                    docs_blocks.DocumentChooserBlock(
                                                                        required=True
                                                                    ),
                                                                ),
                                                            ),
                                                            icon="fa-file",
                                                        ),
                                                    ),
                                                    (
                                                        "url_button",
                                                        core_blocks.StructBlock(
                                                            (
                                                                (
                                                                    "label",
                                                                    core_blocks.TextBlock(
                                                                        required=True
                                                                    ),
                                                                ),
                                                                (
                                                                    "url",
                                                                    core_blocks.URLBlock(
                                                                        required=True
                                                                    ),
                                                                ),
                                                            ),
                                                            icon="fa-link",
                                                        ),
                                                    ),
                                                    (
                                                        "placeholder",
                                                        core_blocks.StructBlock(
                                                            (), icon="fa-square-o"
                                                        ),
                                                    ),
                                                ),
                                                help_text="A button or URL within a button section.",
                                            ),
                                        ),
                                    )
                                ),
                            ),
                        ),
                        null=True,
                    ),
                ),
                (
                    "main_image",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to="wagtailimages.Image",
                    ),
                ),
                (
                    "small_image",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to="wagtailimages.Image",
                    ),
                ),
            ],
            options={"verbose_name": "Grid Item",},
            bases=("wagtailcore.page",),
        ),
        migrations.CreateModel(
            name="GridItemTag",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "content_object",
                    modelcluster.fields.ParentalKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="tagged_items",
                        to="wagtailgridder.GridItem",
                    ),
                ),
                (
                    "tag",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="wagtailgridder_griditemtag_items",
                        to="taggit.Tag",
                    ),
                ),
            ],
            options={"abstract": False,},
        ),
        migrations.AddField(
            model_name="griditem",
            name="tags",
            field=modelcluster.contrib.taggit.ClusterTaggableManager(
                blank=True,
                help_text="A comma-separated list of tags.",
                through="wagtailgridder.GridItemTag",
                to="taggit.Tag",
                verbose_name="Tags",
            ),
        ),
        migrations.AddField(
            model_name="gridindexgriditemrelationship",
            name="grid_relationship",
            field=modelcluster.fields.ParentalKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="grid_index_grid_item_relationship",
                to="wagtailgridder.GridIndexPage",
            ),
        ),
        migrations.AddField(
            model_name="gridindexgriditemrelationship",
            name="grid_item",
            field=models.ForeignKey(
                help_text="Add a grid item to the page",
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="wagtailgridder.GridItem",
                verbose_name="Grid Items",
            ),
        ),
        migrations.AddField(
            model_name="griditem",
            name="landing_page_text",
            field=core_fields.RichTextField(
                blank=True,
                help_text="This is the text which will appear on the grid item's landing page.",
                null=True,
                verbose_name="Landing Page Text",
            ),
        ),
        migrations.RemoveField(model_name="griditem", name="target_url",),
        migrations.RenameField(
            model_name="griditem", old_name="main_image", new_name="description_image",
        ),
        migrations.RenameField(
            model_name="griditem", old_name="full_desc", new_name="description_text",
        ),
        migrations.RenameField(
            model_name="griditem", old_name="small_image", new_name="summary_image",
        ),
        migrations.RenameField(
            model_name="griditem", old_name="summary", new_name="summary_text",
        ),
        migrations.AlterField(
            model_name="griditem",
            name="buttons",
            field=core_fields.StreamField(
                (
                    (
                        "button_section",
                        core_blocks.StructBlock(
                            (
                                (
                                    "action_items",
                                    core_blocks.StreamBlock(
                                        (
                                            (
                                                "document_button",
                                                core_blocks.StructBlock(
                                                    (
                                                        (
                                                            "label",
                                                            core_blocks.TextBlock(
                                                                required=True
                                                            ),
                                                        ),
                                                        (
                                                            "document",
                                                            docs_blocks.DocumentChooserBlock(
                                                                required=True
                                                            ),
                                                        ),
                                                    ),
                                                    icon="fa-file",
                                                ),
                                            ),
                                            (
                                                "url_button",
                                                core_blocks.StructBlock(
                                                    (
                                                        (
                                                            "label",
                                                            core_blocks.TextBlock(
                                                                required=True
                                                            ),
                                                        ),
                                                        (
                                                            "url",
                                                            core_blocks.TextBlock(
                                                                required=True
                                                            ),
                                                        ),
                                                    ),
                                                    icon="fa-link",
                                                ),
                                            ),
                                            (
                                                "placeholder",
                                                core_blocks.StructBlock(
                                                    (), icon="fa-square-o"
                                                ),
                                            ),
                                        ),
                                        help_text="A button or URL within a button section.",
                                    ),
                                ),
                            )
                        ),
                    ),
                ),
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="griditem",
            name="categories",
            field=modelcluster.fields.ParentalManyToManyField(
                blank=True, to="wagtailgridder.GridCategory"
            ),
        ),
        migrations.AddField(
            model_name="gridindexpage",
            name="featured_grid_item_1",
            field=models.ForeignKey(
                blank=True,
                help_text="First featured grid item underneath the hero image.",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="wagtailgridder.GridItem",
                verbose_name="Featured Item One",
            ),
        ),
        migrations.AddField(
            model_name="gridindexpage",
            name="featured_grid_item_2",
            field=models.ForeignKey(
                blank=True,
                help_text="Second featured grid item underneath the hero image.",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="wagtailgridder.GridItem",
                verbose_name="Featured Item Two,",
            ),
        ),
        migrations.AddField(
            model_name="gridindexpage",
            name="hero_background_image",
            field=models.ForeignKey(
                blank=True,
                help_text="The background image for the hero section. This triggers the section to be displayed if an image is selected.",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="wagtailimages.Image",
            ),
        ),
        migrations.AddField(
            model_name="gridindexpage",
            name="hero_logo_image",
            field=models.ForeignKey(
                blank=True,
                help_text="The logo image to be displayed over the background image.",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="wagtailimages.Image",
            ),
        ),
        migrations.AddField(
            model_name="gridindexpage",
            name="featured_description",
            field=models.TextField(
                blank=True,
                help_text="Text to be displayed below the hero image next to the featured items.",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="gridindexpage",
            name="hero_button_text",
            field=models.CharField(
                blank=True,
                help_text="Text for the call-to-action button beneath the text and logo over the background image.",
                max_length=255,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="gridindexpage",
            name="hero_button_url",
            field=models.CharField(
                blank=True,
                help_text="URL for the call-to-action button beneath the text and logo over the background image.",
                max_length=255,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="gridindexpage",
            name="hero_description",
            field=models.TextField(
                blank=True,
                help_text="Text to be displayed beneath the logo over the background image.",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="griditem",
            name="description_video",
            field=models.URLField(
                blank=True,
                help_text="This video will be embedded in the expanded area when populated.",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="griditem",
            name="description_image",
            field=models.ForeignKey(
                blank=True,
                help_text="This image will appear in the expanded area when populated.",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="wagtailimages.Image",
            ),
        ),
        migrations.AlterField(
            model_name="griditem",
            name="description_text",
            field=core_fields.RichTextField(
                blank=True,
                help_text="This description will appear in the expanded area when populated.",
                null=True,
                verbose_name="Full Description",
            ),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.10 on 2018-02-20 16:01
from __future__ import unicode_literals

from django.db import migrations
import wagtail.core.fields


class Migration(migrations.Migration):

    dependencies = [
        ("wagtailgridder", "0001_squashed_0012_auto_20170607_1317"),
    ]

    operations = [
        migrations.AlterField(
            model_name="gridindexpage",
            name="featured_description",
            field=wagtail.core.fields.RichTextField(
                blank=True,
                help_text="Text to be displayed below the hero image next to the featured items.",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="gridindexpage",
            name="hero_description",
            field=wagtail.core.fields.RichTextField(
                blank=True,
                help_text="Text to be displayed beneath the logo over the background image.",
                null=True,
            ),
        ),
    ]



from django.core.cache import cache
from django.urls import reverse
from django.utils.translation import ugettext as _
from wagtail.contrib.modeladmin.helpers import PageButtonHelper

from wagtail.core import hooks

from wagtail.contrib.modeladmin.options import (
    ModelAdmin,
    ModelAdminGroup,
    modeladmin_register,
)

from .models import GridCategory, GridIndexPage
from .settings import get_clear_cache


class PageButtonHelperWithAddChild(PageButtonHelper):
    def create_child_button(self, pk, classnames_add=None, classnames_exclude=None):
        if classnames_add is None:
            classnames_add = []
        if classnames_exclude is None:
            classnames_exclude = []
        classnames = self.edit_button_classnames + classnames_add
        cn = self.finalise_classname(classnames, classnames_exclude)
        return {
            'url': reverse('wagtailadmin_pages:add_subpage', args=[pk]),
            'label': _('Add child page'),
            'classname': cn,
            'title': _('Add a child page to %s') % self.verbose_name,
        }

    def get_buttons_for_obj(self, obj, exclude=None, classnames_add=None,
                            classnames_exclude=None):
        btns = super().get_buttons_for_obj(obj, exclude, classnames_add,
                                           classnames_exclude)
        if classnames_add is None:
            classnames_add = []
        if classnames_exclude is None:
            classnames_exclude = []
        pk = getattr(obj, self.opts.pk.attname)
        btns.append(
            self.create_child_button(pk, classnames_add, classnames_exclude)
        )

        return btns


class GridCategoryAdmin(ModelAdmin):
    model = GridCategory
    menu_label = "Grid Categories"
    menu_icon = "fa-folder-open"
    add_to_settings_menu = False
    list_display = ("name",)
    search_fields = ("name",)


class GridIndexPageAdmin(ModelAdmin):
    model = GridIndexPage
    menu_icon = 'doc-full-inverse'
    list_display = ('title',)
    search_fields = ('title',)
    button_helper_class = PageButtonHelperWithAddChild


class GridAdminGroup(ModelAdminGroup):
    menu_label = "Grid Layouts"
    menu_icon = "fa-th"  # change as required
    menu_order = 400  # will put in 3rd place (000 being 1st, 100 2nd)
    items = (GridCategoryAdmin, GridIndexPageAdmin)


modeladmin_register(GridAdminGroup)


@hooks.register("after_edit_page")
def clear_page_cache(request, page):
    """
    This will clear Django's entire cache after a page edit. It is ugly, but Django's
    cache mechanism doesn't currently support a way to easily clear based on template
    fragments specifics.
    """

    if get_clear_cache():
        cache.clear()



from setuptools import setup, find_packages

with open("README.md") as f:
    long_description = f.read()

setup(
    name="wagtailgridder",
    description="Gridder layout for the Django CMS Wagtail.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Timothy Allen",
    author_email="tallen@wharton.upenn.edu",
    url="https://github.com/wharton/wagtailgridder",
    include_package_data=True,
    packages=find_packages(),
    zip_safe=False,
    install_requires=["wagtail>=2.0"],
    setup_requires=["setuptools_scm"],
    use_scm_version=True,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Framework :: Django",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
    ],
)
